ChangeLog
=========


1.0.4 2019-06-17
--------------

- Added support for BooleanField and FileField


1.0.3 2019-06-17
--------------

- Added more coverage
- Added FR translation
- Added HistoryBaseModel


1.0 2019-06-14
--------------

- Initial Release
